import {
  scaleLinear,
  scaleTime,
  timeFormat,
  extent,
  bin,
  timeMonths,
  sum,
  max,
} from 'd3';
import { AxisBottom } from './AxisBottom';
import { AxisLeft } from './AxisLeft';
import { Marks } from './Marks';

export const DateHistogram = ({ data, width, height }) => {
  const margin = {
    top: 0,
    right: 30,
    bottom: 20,
    left: 45,
  };
  const xAxisLabelOffset = 54;
  const yAxisLabelOffset = 30;

  const innerHeight = height - margin.top - margin.bottom;
  const innerWidth = width - margin.left - margin.right;

  const xValue = (d) => d['Reported Date'];
  const xAxisLabel = 'Time';

  const yValue = (d) => d['Total Dead and Missing'];
  const yAxisLabel = 'Total Dead and Missing';

  const xAxisTickFormat = timeFormat('%m/%d/%Y');

  const xScale = scaleTime()
    .domain(extent(data, xValue))
    .range([0, innerWidth])
    .nice();

  ////**** Binned Aggregation ****////
  //** 1. Binning **//
  const [start, end] = xScale.domain();

  //console.log("data", data);
  const binnedData = bin()
    .value(xValue)
    .domain(xScale.domain())
    .thresholds(timeMonths(start, end))(data);
  //console.log("binnedData", binnedData);

  //** 2. Aggregation (with sum) **//
  const aggregatedData = binnedData.map((array) => ({
    y: sum(array, yValue),
    x0: array.x0,
    x1: array.x1,
  }));
  //console.log(aggregatedData);

  const yScale = scaleLinear()
    .domain([0, max(aggregatedData, (d) => d.y)])
    .range([innerHeight, 0]);

  return (
    <>
      <rect width={width} height={height} fill="white" />
      <g
        transform={`translate(${margin.left},${margin.top})`}
      >
        <AxisBottom
          xScale={xScale}
          innerHeight={innerHeight}
          tickFormat={xAxisTickFormat}
          tickOffset={5}
        />
        <text
          className="axis-label"
          textAnchor="middle"
          transform={`translate(${-yAxisLabelOffset},${
            innerHeight / 2
          }) rotate(-90)`}
        >
          {yAxisLabel}
        </text>
        <AxisLeft
          yScale={yScale}
          innerWidth={innerWidth}
          tickOffset={5}
        />
        <text
          className="axis-label"
          x={innerWidth / 2}
          y={innerHeight + xAxisLabelOffset}
          textAnchor="middle"
        >
          {xAxisLabel}
        </text>
        <Marks
          data={aggregatedData}
          xScale={xScale}
          yScale={yScale}
          tooltipFormat={(d) => d}
          innerHeight={innerHeight}
        />
      </g>
    </>
  );
};
